Learn R Programming

rSpectral (version 1.0.0.14)

spectral_igraph_communities: Spectral clustering for igraph objects

Description

This function invoke spectral_igraph_membership to calculate clustering and convert it into communities object for seamless work with native igraph clustering functions.

Usage

spectral_igraph_communities(
  g,
  Cn_min = 1L,
  tol = 1e-05,
  names = 1L,
  fix_neig = 0L
)

Value

communities object

Arguments

g

igraph object

Cn_min

minimum cluster size

tol

tolerance

names

are we dealing with alphaNumeric (1) or numeric (!1) ids

fix_neig

whether to fix neighbouring nodes found in same community

Examples

Run this code
data(karate,package='igraphdata')
c<-spectral_igraph_communities(karate)

Run the code above in your browser using DataLab