powered by
igraph
This function invoke spectral_igraph_membership to calculate clustering and convert it into communities object for seamless work with native igraph clustering functions.
spectral_igraph_membership
communities
spectral_igraph_communities( g, Cn_min = 1L, tol = 1e-05, names = 1L, fix_neig = 0L )
communities object
igraph object
minimum cluster size
tolerance
are we dealing with alphaNumeric (1) or numeric (!1) ids
whether to fix neighbouring nodes found in same community
data(karate,package='igraphdata') c<-spectral_igraph_communities(karate)
Run the code above in your browser using DataLab